Crate miden_node_db

Crate miden_node_db 

Modules

migration
Provides a framework for SQLite migrations.

Structs

ConnectionManager
Create a connection manager with per-connection setup
DatabaseTypeConversionError
Db
Database handle that provides fundamental operations that various components of Miden Node can utililze for their storage needs.
PinnedConnection
A connection checked out of Db’s pool and held for the caller’s exclusive, long-lived use.

Enums

ConnectionManagerError
DatabaseError
SchemaVerificationError
Errors that can occur during schema verification.

Traits

SqlTypeConvert
Convert from and to it’s database representation and back

Functions

configure_connection_on_creation
default_connection_pool_size
Returns the default SQLite connection pool size.

Type Aliases

Result