pub enum DatabaseError {
InteractError(String),
ConnectionPoolObtainError(Box<dyn Error + Send + Sync + 'static>),
ConversionSqlToRust {
inner: Option<Box<dyn Error + Send + Sync + 'static>>,
to: &'static str,
},
Rusqlite(Error),
Migration(Box<dyn Error + Send + Sync + 'static>),
SchemaVerification(SchemaVerificationError),
Io(Error),
PoolBuild(BuildError),
ConversionError(DatabaseTypeConversionError),
}Variants
InteractError(String)
ConnectionPoolObtainError(Box<dyn Error + Send + Sync + 'static>)
ConversionSqlToRust
Rusqlite(Error)
Migration(Box<dyn Error + Send + Sync + 'static>)
SchemaVerification(SchemaVerificationError)
Io(Error)
PoolBuild(BuildError)
ConversionError(DatabaseTypeConversionError)
Implementations
Sourceimpl DatabaseError
impl DatabaseError
Sourcepub fn interact(msg: &(impl ToString + ?Sized), e: &InteractError) -> Self
pub fn interact(msg: &(impl ToString + ?Sized), e: &InteractError) -> Self
Converts from InteractError
Note: Required since InteractError has at least one enum
variant that is not Send + Sync and hence prevents the
Sync auto implementation.
This does an internal conversion to string while maintaining
convenience.
Using MSG as const so it can be called as
.map_err(DatabaseError::interact::<"Your message">)
Sourcepub fn migration(
source: impl Into<Box<dyn Error + Send + Sync + 'static>>,
) -> Self
pub fn migration( source: impl Into<Box<dyn Error + Send + Sync + 'static>>, ) -> Self
Creates a database migration error with the original source error.
Sourcepub fn conversiont_from_sql<RT, E, MaybeE>(err: MaybeE) -> DatabaseError
pub fn conversiont_from_sql<RT, E, MaybeE>(err: MaybeE) -> DatabaseError
Failed to convert an SQL entry to a rust representation
Sourcepub fn deserialization(
context: &'static str,
source: impl Error + Send + Sync + 'static,
) -> Self
pub fn deserialization( context: &'static str, source: impl Error + Send + Sync + 'static, ) -> Self
Creates a deserialization error with a static context string and the original error.
This is a convenience wrapper around ConversionSqlToRust.