pub trait ToSqlValue {
// Required method
fn to_sql_value(&self) -> DbValue;
}Expand description
Converts a Rust value into its SQL parameter representation (the write side of the codec).
Required Methods
Sourcefn to_sql_value(&self) -> DbValue
fn to_sql_value(&self) -> DbValue
Returns the SQL value bound for this Rust value.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl ToSqlValue for Account
impl ToSqlValue for Account
fn to_sql_value(&self) -> DbValue
Sourceimpl ToSqlValue for AccountCode
impl ToSqlValue for AccountCode
fn to_sql_value(&self) -> DbValue
Sourceimpl ToSqlValue for AccountId
impl ToSqlValue for AccountId
fn to_sql_value(&self) -> DbValue
Sourceimpl ToSqlValue for AccountStorageHeader
impl ToSqlValue for AccountStorageHeader
fn to_sql_value(&self) -> DbValue
Sourceimpl ToSqlValue for Asset
impl ToSqlValue for Asset
fn to_sql_value(&self) -> DbValue
Sourceimpl ToSqlValue for BlockHeader
impl ToSqlValue for BlockHeader
fn to_sql_value(&self) -> DbValue
Sourceimpl ToSqlValue for BlockNumber
impl ToSqlValue for BlockNumber
fn to_sql_value(&self) -> DbValue
Sourceimpl ToSqlValue for BlockSignatures
impl ToSqlValue for BlockSignatures
fn to_sql_value(&self) -> DbValue
Sourceimpl ToSqlValue for Felt
A field element is stored as the bit reinterpretation of its canonical u64.
impl ToSqlValue for Felt
A field element is stored as the bit reinterpretation of its canonical u64.