DatabaseError

Enum DatabaseError 

pub enum DatabaseError {
    InteractError(String),
    ConnectionPoolObtainError(Box<dyn Error + Send + Sync + 'static>),
    ConversionSqlToRust {
        inner: Option<Box<dyn Error + Send + Sync + 'static>>,
        to: &'static str,
    },
    Diesel(Error),
    SchemaVerification(SchemaVerificationError),
    Io(Error),
    PoolBuild(BuildError),
    Pool(PoolError<Error>),
}

Variants



InteractError(String)



ConnectionPoolObtainError(Box<dyn Error + Send + Sync + 'static>)



ConversionSqlToRust

Fields

inner: Option<Box<dyn Error + Send + Sync + 'static>>
to: &'static str


Diesel(Error)



SchemaVerification(SchemaVerificationError)



Io(Error)



PoolBuild(BuildError)



Pool(PoolError<Error>)

Implementations

Source

impl DatabaseError

pub fn interact(msg: &(impl ToString + ?Sized), e: &InteractError) -> Self

Converts from InteractError

Note: Required since InteractError has at least one enum variant that is not Send + Sync and hence prevents the Sync auto implementation. This does an internal conversion to string while maintaining convenience.

Using MSG as const so it can be called as .map_err(DatabaseError::interact::<"Your message">)

pub fn conversiont_from_sql<RT, E, MaybeE>(err: MaybeE) -> DatabaseError
where MaybeE: Into<Option<E>>, E: Error + Send + Sync + 'static,

Failed to convert an SQL entry to a rust representation

pub fn deserialization( context: &'static str, source: impl Error + Send + Sync + 'static, ) -> Self

Creates a deserialization error with a static context string and the original error.

This is a convenience wrapper around ConversionSqlToRust.